<?php

namespace App\Http\Controllers\Admin;
use App\Http\Requests\UserRequest;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use App\Models\User;
use App\Models\Post;
use App\Models\Role;
use App\Models\Permission;
use Session;
use File;


class UserController extends Controller
{
  
    public function __construct()
    {
       $this->middleware('auth:admin');
    }

    public function index() {

		$users = User::all();
    	return view('admin.users.index',compact('users'));
        
    }

    public function create() {

        $roles = Role::where('guard_name','web')->pluck('name','id')->toArray();
        $user_roles = NULL;
    	return view('admin.users.create',compact('roles','user_roles'));
       
    }

    public function store(UserRequest $request) {

        $role = $request->role;
        $reqRoles = [];
        for($i = 0; $i < count($role); $i++){
            $reqRoles[$i] = Role::find($role[$i]);
        }
        $input = $request->all();
        $input['password'] = Hash::make($input['password']);
        $user = User::create($input);
        $user->roles()->saveMany($reqRoles);

        if($user){
           Session::flash('success', 'User Created Successfully'); 
        } else {
           Session::flash('danger', 'Error Encounterd');
        }
        return redirect()->route('admin.users.list');
    }

    public function show($id) {
        
        $user = User::findOrFail($id);

        $permissions = Permission::where('guard_name','web')->get();
        $user_permissions =  $user->permissions->pluck('id')->toArray();

        $all_perm=[];
        $permmision_arr = [];
        $user_role_permissions = [];
        foreach($user->roles as $role){

            $permmision_arr = is_array($role->getPermIdsAttribute()) ? $role->getPermIdsAttribute() : array();
            $all_perm = array_merge($all_perm, $permmision_arr);         

        }

        $unique_permissions = array_unique($all_perm);


        for($i = 0; $i < count($unique_permissions); $i++){
            $user_role_permissions[$i] = Permission::find($unique_permissions[$i]);
        }

        return view('admin.users.show', compact('user','permissions','user_permissions','user_role_permissions'));

    }

    public function edit($id) {

         $user = User::findOrFail($id);
         $roles = Role::where('guard_name','web')->pluck('name','id')->toArray();
         $user_roles = $user->roles;
         return view('admin.users.edit',compact('user','roles','user_roles'));
    }

    public function update(UserRequest $request, $id) {

        $input = $request->only('name','email','role');
        $user = User::findOrFail($id);
        $user->roles()->sync($input['role']);
        /*if($request->hasFile('image'))
        {
            $destinationPath = 'uploads';
            $file = $request->file('image');
            $original_name = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
            $extension = $file->getClientOriginalExtension();
            $filename=time().rand(100,999).$original_name.'.'.$extension;
            
            $file->move(
                config('services.new_root_path').$destinationPath, $filename
            );
            
            

            $input['image'] = $filename;

            if ($user->image) {
                    File::delete(config('services.new_root_path').'uploads/'.$user->image);
                    
                }
        }*/
        $result = $user->update($input);
        if($result){
           Session::flash('success', 'User Updated Successfully'); 
        } else {
           Session::flash('danger', 'Error Encounterd');
        }
        if($request->Submit == 'update'){
            return redirect()->route('admin.users.list');
        }else{
            return redirect()->back();
        }
        
    }

    public function destroy($id) {

        $result = User::findOrFail($id)->delete();
        Post::where('user_id',$id)->update(['user_id' => 0]);
        if($result){
           Session::flash('success', 'User Deleted Successfully'); 
        } else {
           Session::flash('danger', 'Error Encounterd');
        }
        return redirect()->route('admin.users.list');
    }  

    public function showPasswordFrom($id) {

    	 $user = User::findOrFail($id);
         return view('admin.users.edit',compact('user'));

    }

    public function changePassword(UserRequest $request, $id) {

        $user = User::findOrFail($id);
        $user->password = Hash::make($request->input('password'));
        $result = $user->update();
        if($result){
           Session::flash('success', 'User Password Created Successfully'); 
        } else {
           Session::flash('danger', 'Error Encounterd');
        }
        return redirect()->route('admin.users.list');

    }

    public function changeStatus(UserRequest $request) {

        if ($request->ajax()) {
                $user = User::findOrFail($request->input('id'));
                $user->status = $request->input('status');
                $result = $user->update();
                        if($result) {
                                return response()->json(['status' => true, 'success' => 'User Status Updated Successfully']);
                        } else {
                                return response()->json(['status' => false, 'danger' => 'Error Encounterd']);
                        }
                    }
        }

     public function multiple_user_delete(UserRequest $request) {

        $items = $request->only('item');
        $result = User::destroy($items['item']);
        Post::whereIn('user_id',$items['item'])->update(['user_id' => 0]);
        if($result){
           Session::flash('success', count($items['item']).' User Deleted Successfully'); 
        } else {
           Session::flash('danger', 'Error Encounterd');
        }
        return redirect()->route('admin.users.list');


    }

    public function truncate() {

        $result = User::truncate();
        DB::table('posts')->update(['user_id' => 0]);

        if($result){
           Session::flash('success', 'User Data Table is Empty Now'); 
        } else {
           Session::flash('danger', 'Error Encounterd');
        }
        
        return redirect()->route('admin.users.list');


    }

    public function manage(UserRequest $request){

        if ($request->ajax() && $request->isMethod('POST')) {

            $input = $request->only('guard','user_id','permission_id');

            $user = User::findOrFail($request->user_id);

            $request->isChecked == 'true' ? $user->permissions()->attach($request->permission_id) : $user->permissions()->detach($request->permission_id);

            $msg = $request->isChecked ? 'Permission is attached successfully' : 'Permission is detached successfully';

            return response()->json(['status' => true, 'success' => $msg]);

        }else{

            return response()->json(['status' => false, 'danger' => 'Error encounterd']);

        }

    }   
}
