<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests\ContactFromRequest;
use App\Http\Requests\AppoinmentFormRequest;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use App\Models\Post;
use App\Models\PostMeta;
use App\Models\Setting;
use App\Models\Category;
use App\Models\ContactForm;
use App\Models\Subscriber;
use App\Models\Menu;
use Session;
use App\Models\AppoinmentRequest;


class PageController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
      $setting = Setting::firstOrFail();
      $this->site_title = $setting->title;
      $this->emails =  $setting->emails;
      $this->cc_emails = $setting->cc_emails;
      $this->bcc_emails = $setting->bcc_emails;
      $this->secret_key = $setting->secret_key;
      $this->logo = $setting->logo;
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

      $page = Post::where([['post_type','page'],['is_front_page',1],['status', 1]])->firstOrFail();
      $meta_html = $this->get_meta_information($page->post_meta_element);
      return view('page_templates.home',compact('page','meta_html')); 
        
    }
    
    public function other($slug)
    {        
        $post_type  = check_post_type($slug);
        //dd($post_type);
        
     $page = Post::with('menu')->whereHas('menu', function($query) {
            $query->where('parent_page', '=', 0);
        })->where([['post_type','page'],['slug',$slug],['status', 1]])->firstOrFail();
        
        $meta_html = $this->get_meta_information($page->post_meta_element);

        if($page->template == 4){

          return view('page_templates.contact',compact('page','meta_html')); 

        }elseif($page->template == 5){

          return view('page_templates.blog',compact('page','meta_html')); 

        }elseif($page->template == 6){

          return view('page_templates.price',compact('page','meta_html')); 

        }elseif($page->template == 7){

          return view('page_templates.fullwidth',compact('page','meta_html')); 

        }elseif($page->template == 8){

          return view('page_templates.emergencydentist',compact('page','meta_html')); 

        }else{

          return view('page_templates.default',compact('page','meta_html')); 

        }
        
             
    }
    
    public function othersub($parent,$slug){

        $post_type  = check_post_type($slug);
      if($post_type == 'page'){
            
          $parent_page = Post::where([['post_type','page'],['slug',$parent]])->firstOrFail();
        
          $page = Post::with('menu')->whereHas('menu', function($query) use($parent_page) {
              $query->where('parent_page', '=', $parent_page->id);
          })->where([['post_type','page'],['slug',$slug],['status', 1]])->firstOrFail();
          
          $meta_html = $this->get_meta_information($page->post_meta_element);
          
          if($page->template == 4){

            return view('page_templates.contact',compact('page','meta_html')); 

          }elseif($page->template == 6){

             return view('page_templates.full-width',compact('page','meta_html')); 

          }else{

             return view('page_templates.default',compact('page','meta_html')); 

          }
       }else{

            $category = Category::select('id','title')->where([['slug','=',$parent],['post_status', 1]])->firstOrFail();
            $cat_id = $category->id;  
            $post = Post::where([['post_type','post'],['slug',$slug],['status', 1]])->whereHas('categories', function($query) use($cat_id) {
                    $query->where('category_id',$cat_id);
                })->firstOrFail();
            $meta_html = $this->get_meta_information($post->post_meta_element);
            return view('page_templates.single',compact('post','meta_html'));
        }
        
        
    }


    public function contact_form(ContactFromRequest $request){
        
   $recaptcha=$request['recaptcha_response'];


      if(!empty($recaptcha)){
       $recaptcha_url = 'https://www.google.com/recaptcha/api/siteverify';
    $recaptcha_secret = $this->secret_key;
    $recaptcha_response = $_POST['recaptcha_response'];

    // Make and decode POST request:
    $recaptcha = file_get_contents($recaptcha_url . '?secret=' . $recaptcha_secret . '&response=' . $recaptcha_response);
    $recaptcha = json_decode($recaptcha);
      
     
      $data = array(

        'name' => strip_tags($request->name),

        'email' => strip_tags($request->email),
        
        'phone' => strip_tags($request->phone),

        'message' => strip_tags($request->message),
       
      );


     if($recaptcha->success==1){ 

      //$result = $this->sendmail($data); 
        $subject= $this->site_title." | New Contact Request ".$request->name;
       $message = $this->email_template($data);
       $result = $this->sendgridEmail($subject,$message);

        if($result){
             $result2 = ContactForm::create($data);

            Session::flash('success', '<h2>Your information has been submitted successfully</h2>'); 

        } else {

            Session::flash('danger', '<h2>Your information has not been submitted successfully</h2>');

        }

      }else{

          Session::flash('danger', '<h2>Error! reCAPTCHA verification failed</h2>');         

      }

    }else{

        Session::flash('danger', '<h2>Error! reCAPTCHA verification is mandatory</h2>'); 

    }

    return redirect()->route('thankyou');

  }

  public function email_template(array $request){

       
        $message = '<!DOCTYPE HTML>'.

        '<head>'.

        '<meta http-equiv="content-type" content="text/html">'.

        '<title>'.$this->site_title.' | New Contact Request '.$request['name'].'</title>'.

        '</head>'.

        '<body>'.

        '<div id="outer" style="width: 80%;margin: 0 auto;margin-top: 10px;">'.

           '<div id="inner" style="width: 78%;margin: 0 auto;background-color: #fff;font-family: Open Sans,Arial,sans-serif;font-size: 13px;font-weight: normal;line-height: 1.4em;color: #444;margin-top: 10px;">'.

               '<p>Name : ' . $request['name'].'</p>'.

               '<p>Email: ' . $request['email'].'</p>'.
               
               '<p>Phone: ' . $request['phone'].'</p>'.
              
               '<p>Message : ' . $request['message'] .'</p>'.

           '</div>'. 

        '</div>'.

        '</body>';

       
      return $message;

  }


  public function booking_enquiry(AppoinmentFormRequest $request){

      $recaptcha=$request['g-recaptcha-response'];

      if(!empty($recaptcha)){

      $google_url="https://www.google.com/recaptcha/api/siteverify";

      $secret=$this->secret_key;

      $ip=$_SERVER['REMOTE_ADDR'];

      $url=$google_url."?secret=".$secret."&response=".$recaptcha."&remoteip=".$ip;

      $res=$this->getCurlData($url);

      $response = json_decode($res, true);
    
    //$package_det = explode("@",$request->package);
     $package_name = $request->package;


      //$package_name = $package_det[0];

      //$price = $package_det[1];
      
         $services='';
    foreach ($request->services as $ser) {
      $services.=$ser.', ';
    }

      $data = array(

        'name' => strip_tags($request->name),

        'select_date' => strip_tags($request->select_date),

        'select_time' => strip_tags($request->select_time),
    
        'email' => strip_tags($request->email),

        'phone' => strip_tags($request->phone),

        'services' =>rtrim($services,','),

        'notes' => strip_tags($request->notes),

      );
      
    

      if($response['success']){ 

        $subject= $$this->site_title." | New Appoinment Request from ".$data['name'];
        $message = $this->email_template2($data);
        $result = $this->sendgridEmail($subject,$message);

        if($result){           
            
        $result2 = AppoinmentRequest::create($data);
            
        $data['website'] = url('/');       

            Session::flash('success', '<h2>Thank you for booking an appointment for for <b>'.$data['select_date'].'</b> at <b>'. $data['select_time'] .'</b> which has now been confirmed.</h2><h3>If you are going to be late, please let us know as soon as possible.'); 

        } else {

            Session::flash('danger', '<h2>Your information has not been submitted successfully</h2>');

        }

      }else{

          Session::flash('danger', '<h2>Error! reCAPTCHA verification failed</h2>');         

      }

    }else{

        Session::flash('danger', '<h2>Error! reCAPTCHA verification is mandatory</h2>'); 

    }

    return redirect()->route('thankyou');

  }

  public function email_template2(array $request){

    
    
    $message = '<html><body>';
    $message .= '<h2>New Appoinment Request Receive</h2>';
    $message .= '<table rules="all" style="border-color: #666;" cellpadding="10">';
    $message .= "<tr style='background: #eee;'><td><strong>Name :</strong> </td><td>" . $request['name'] . "</td></tr>";
    $message .= "<tr><td><strong>Email :</strong> </td><td>" . $request['email'] . "</td></tr>";
    $message .= "<tr><td><strong>Phone :</strong> </td><td>" . $request['phone'] . "</td></tr>";
    $message .= "<tr><td><strong>Date :</strong> </td><td>" . $request['select_date'] . "</td></tr>";
    $message .= "<tr><td><strong>Time :</strong> </td><td>" . $request['select_time'] . "</td></tr>";

      $message .= "<tr><td><strong>Services :</strong> </td><td>" . $request['services']  . "</td></tr>";
    
    if(isset($request['notes']) || !empty($request['notes'])){

          $message .= "<tr><td><strong>Message :</strong> </td><td>" . $request['notes']  . "</td></tr>";
        }

    $message .= "</table>";
    $message .= "</body></html>";
 

     
      return $message;



  }









  public function getCurlData($url)

  {

    $curl = curl_init();

    curl_setopt($curl, CURLOPT_URL, $url);

    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);

    curl_setopt($curl, CURLOPT_TIMEOUT, 10);

    curl_setopt($curl, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US; rv:1.9.2.16) Gecko/20110319 Firefox/3.6.16");

    $curlData = curl_exec($curl);

    curl_close($curl);

    return $curlData;

  }

  
  public function thankyou(){
  
    if(Session::has('success') || Session::has('danger')) {

      return view('page_templates.thankyou');
    
    }else{
    
    return redirect()->action('PageController@index');  
    
    }

     

  } 
  
  


  
  public function postCurlData($url,$fields){
  
  $fields_string = '';
  foreach($fields as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
  rtrim($fields_string, '&');
  $ch = curl_init();
  curl_setopt($ch,CURLOPT_URL, $url);
  curl_setopt($ch,CURLOPT_POST, count($fields));
  curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);
  curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true); 
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
  $result = curl_exec($ch);
  curl_close($ch);
  return $result;
  
  }

  

  public function get_meta_information($meta){
      
      if($meta->title){

          $meta_info = '<title>'. $meta->title . '</title>'.PHP_EOL;
      }
      if($meta->description){
        
          $meta_info .= '<meta name="description" content="'. $meta->description .'" />'.PHP_EOL;
      }
      if($meta->keywords){
          
          $meta_info .= '<meta name="keywords" content="'. $meta->keywords .'" />'.PHP_EOL;

      }
      if($meta->robots){
          
          $meta_info .= '<meta name="robots" content="'. $meta->robots .'" />'.PHP_EOL;

      }
      if($meta->revisit_after){
          
          $meta_info .= '<meta name="revisit-after" content="'. $meta->revisit_after .'" />'.PHP_EOL;

      }
      if($meta->og_locale){
          
          $meta_info .= '<meta property="og:locale" content="'. $meta->og_locale .'" />'.PHP_EOL;

      }
      if($meta->og_type){
          
          $meta_info .= '<meta property="og:type" content="'. $meta->og_type .'" />'.PHP_EOL;

      }
      if($meta->og_image){
          
          $meta_info .= '<meta property="og:image" content="'. $meta->og_image .'" />'.PHP_EOL;
      }
      if($meta->og_title){
          
          $meta_info .= '<meta property="og:title" content="'. $meta->og_title .'" />'.PHP_EOL;

      }
      if($meta->og_url == NULL){

        $uri = $_SERVER['REQUEST_URI'];
        $protocol = ((!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off') || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
        $url = $protocol . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
          
        $meta_info .= '<meta property="og:url" content="'. $url .'" />'.PHP_EOL;
      }
      if($meta->og_description){
          
          $meta_info .= '<meta property="og:description" content="'. $meta->og_description .'" />'.PHP_EOL;
      }
      if($meta->og_site_name){
          
          $meta_info .= '<meta property="og:site_name" content="'. $meta->og_site_name .'" />'.PHP_EOL;

      }
      if($meta->author){
          
          $meta_info .= '<meta name="author" content="'. $meta->author .'" />'.PHP_EOL;
      }
      if($meta->canonical == NULL){

        $uri = $_SERVER['REQUEST_URI'];
        $protocol = ((!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off') || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
        $url = $protocol . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];

        $meta_info .= '<link rel="canonical" href="'. $url .'" />'.PHP_EOL;
      }
      if($meta->geo_region){
          
          $meta_info .= '<meta name="geo.region" content="'. $meta->geo_region .'" />'.PHP_EOL;
      }
      if($meta->geo_placename){
          
          $meta_info .= '<meta name="geo.placename" content="'. $meta->geo_placename .'" />'.PHP_EOL;
      }
      if($meta->geo_position){
          
          $meta_info .= '<meta name="geo.position" content="'. $meta->geo_position .'" />'.PHP_EOL;
      }
      if($meta->ICBM){
          
          $meta_info .= '<meta name="ICBM" content="'. $meta->ICBM .'" />';
      }

      return $meta_info;
  }


  public function generate_time_step(Request $request){
      
    $dayofweek = date('w', strtotime($request->date));
    

    
    if($dayofweek == 0 || $dayofweek == 6){
        
       $range=range(strtotime($request->date .$_POST['wend_start']),strtotime($request->date .$_POST['wend_end']),60*60);
       
    }else{
        
        $range=range(strtotime($request->date .$_POST['wday_start']),strtotime($request->date .$_POST['wday_end']),60*60);
            
    }
   
    
  
  
    $result = '';   
  //  $url='http://account.stdcheck.london/v1/check-availibility.php';

  $data['select_date'] = date('l',strtotime($request->date)).' - '.$request->date;
  //$response = $this->postCurlData($url,$data);
  //$response = json_decode($response);
  $time_arr = [];
  /*foreach($response->data as $time){
    $time_arr[] = strtotime($request->date . ' '.$time);
  }*/
    foreach($range as $time){
       if($time <= strtotime(date('Y-m-d h:i:sa')) || in_array( $time, $time_arr)){
         $class = 'disabled';
         $disabled = 'disabled="disabled"';
       }else{
          $class = "";
          $disabled = "";
       }
       
       if($time <= strtotime(date('Y-m-d h:i:sa')) && in_array( $time, $time_arr)){
     $span='<span class="tooltiptext">Time over and schedule booked</span>';
       }
       elseif($time <= strtotime(date('Y-m-d h:i:sa'))){
         $span='<span class="tooltiptext">Time over</span>';
       }
       elseif(in_array( $time, $time_arr)){
        $span='<span class="tooltiptext">Schedule booked</span>';
       }      
       else{
        $span='';
       }
       
          $result .= '<div class="col-md-3 col-4 col-lg-2">';
          $result .=  '<div class="select-time">'.$span;
          $result .=    '<input type="radio" name="select_time" onclick="next()" class="'. $class .'"  value="'.date("g:i A",$time).'" '.$disabled.'>';
          $result .=    '<div class="select-time-inner">';
          $result .=      '<p>'.date("g:i A",$time) .'</p>';
          //$result .=      '<p>'. date("g:i A",strtotime("+30 minutes", $time)) .'</p>';
          $result .=    '</div>';
          $result .=   '</div>';
          $result .= '</div>';
      }  

      echo $result;
  } 
  



  
   public function sendgridEmail($subject,$message){
      
$headers = "MIME-Version: 1.0" . "\r\n";

            $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";

            $headers .= 'From: <info@bayswaterdental.co.uk>' . "\r\n";
        
          if($this->cc_emails){

      $headers .= 'Cc: '.$this->cc_emails . "\r\n";

      }

      if($this->bcc_emails){

      $headers .= 'Bcc: '.$this->bcc_emails . "\r\n";

      }

      $result = mail($this->emails,$subject,$message,$headers);
     
      
      return  $result;
    }



    
}