<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Route;


class UserRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {

        $routeName = Route::currentRouteName();

        switch($routeName)
        {
            case 'admin.user.store':
            {
                return [ 
                        'name' => 'required|regex:/^[\pL\s\-]+$/u',
                        'email' => 'required|email|unique:users,email',
                        'password' => 'required|string|min:8|same:conf_password',
                        'conf_password' => 'required',
                        'role' => 'required|array'
                      ];
            }
            case 'admin.user.update':
            {
                return [ 
                        'name' => 'required|regex:/^[\pL\s\-]+$/u',
                        'email' => 'required|email|unique:users,email,'.$this->id,
                        'role' => 'required|array'
                       ];
            }
            case 'admin.user.password.create':
            {
                return [ 
                        'password' => 'required|string|min:8|same:conf_password',
                        'conf_password' => 'required'
                       ];
            }
            case 'admin.users.delete':
            {
                return [ 
                        'item' => 'required|array'
                       ];
            }
            case 'admin.user.change_status':
            {
                return [ 
                        'status' => 'required|numeric',
                        'id' => 'required|numeric'
                       ];
            }
            case 'admin.user.permissions.manage':
            {
                return [ 
                        'guard' => 'required|string',
                        'permission_id'   => 'required|integer',
                        'user_id' => 'required|integer',
                        'isChecked' => 'required'
                       ];
            }
            default:break;
        }

        
    }

    public function messages()
    {
        return [ 
            'name.required' => 'Please enter a name',
            'name.regex' => 'Please enter a valid name',
            'email.required' => 'Please enter an email',
            'email.email' => 'Please enter a valid email',
            'email.unique' => 'This email is already exists',
            'password.required' => 'Please enter a password',
            'password.min' => 'Please enter a secure password (atleast 8 char)',
            'password.same' => 'The password and confirmed password must match.',
            'conf_password.required' => 'Please enter confirm password'
        ];
    }
}
