<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
use App\Http\Controllers\Admin\PageController;

Route::get('/clear-cache', function() {
    Artisan::call('view:clear');
    Artisan::call('cache:clear');
    Artisan::call('config:clear');
    Artisan::call('route:clear');
    return "Cache is cleared";
});

//Route::get('/login', 'Auth\LoginController@showLoginForm')->name('login');

Route::group(['as' => 'admin.', 'prefix' => 'admin', 'namespace' => 'Admin', 'middleware' => 'prevent-back-history'], function() {

	// Route::get('/register', 'Auth\RegisterController@showRegistrationForm')->name('register');
    // Route::post('/register', 'Auth\RegisterController@register')->name('register');
	Route::get('/login', 'Auth\LoginController@showLoginForm')->name('login');
    Route::post('/login', 'Auth\LoginController@login')->name('login.submit');
    Route::post('/logout', 'Auth\LoginController@adminLogout')->name('logout');
    // Route::post('/password/email', 'Auth\ForgotPasswordController@sendResetLinkEmail')->name('password.email');
    // Route::get('/password/reset', 'Auth\ForgotPasswordController@showLinkRequestForm')->name('password.request');
    // Route::post('/password/reset', 'Auth\ResetPasswordController@reset')->name('password.update');
    // Route::get('/password/reset/{token}', 'Auth\ResetPasswordController@showResetForm')->name('password.reset');
    Route::get('/', 'AdminController@index')->name('dashboard');

    Route::get('/users', 'UserController@index')->name('users.list')->middleware('permission:admin.users.list');
    Route::get('/user/create', 'UserController@create')->name('user.create')->middleware('permission:admin.user.create');
    Route::post('/user/create', 'UserController@store')->name('user.store')->middleware('permission:admin.user.store');
    Route::get('/user/edit/{id}', 'UserController@edit')->name('user.edit')->middleware('permission:admin.user.edit');
    Route::patch('/user/update/{id}', 'UserController@update')->name('user.update')->middleware('permission:admin.user.update');
    Route::get('/user/change_password/{id}', 'UserController@showPasswordFrom')->name('user.change_password')->middleware('permission:admin.user.change_password');
    Route::patch('/user/change_password/{id}', 'UserController@changePassword')->name('user.password.create')->middleware('permission:admin.user.password.create');
    Route::get('/user/show/{id}', 'UserController@show')->name('user.show')->middleware('permission:admin.user.show');
    Route::post('/user/changestatus', 'UserController@changeStatus')->name('user.change_status')->middleware('permission:admin.user.change_status');
    Route::get('/user/delete/{id}', 'UserController@destroy')->name('user.delete')->middleware('permission:admin.user.delete');
    Route::post('/users/delete', 'UserController@multiple_user_delete')->name('users.delete')->middleware('permission:admin.users.delete');
    #Route::get('/users/truncate', 'UserController@truncate')->name('users.truncate');
    Route::post('/set-unset-user-permission', 'UserController@manage')->name('user.permissions.manage')->middleware('permission:admin.user.permissions.manage');

    Route::match(['get','patch'],'/settings', 'SettingController@update')->name('site.setting');
    Route::match(['get','patch'],'/profile', 'AdminController@profile')->name('profile');
    Route::match(['get','patch'],'/change_password', 'AdminController@change_password')->name('change_password');
    Route::match(['get','post','patch'],'/widgets', 'WidgetController@manage')->name('widgets');
    Route::delete('/widget/delete/{id}', 'WidgetController@destroy')->name('widget.delete');
    Route::get('/widgets/truncate', 'WidgetController@truncate')->name('widgets.truncate');
    Route::match(['get','post'],'/seo-setting', 'SeoSettingController@manage')->name('seo.setting');

    Route::get('/categories', 'CategoryController@index')->name('categories.list');
    Route::get('/category/create', 'CategoryController@create')->name('category.create');
    Route::post('/category/create', 'CategoryController@store')->name('category.store');
    Route::get('/category/edit/{id}', 'CategoryController@edit')->name('category.edit');
    Route::put('/category/slug/update', 'CategoryController@slug')->name('category.update.slug');
    Route::patch('/category/update/{id}', 'CategoryController@update')->name('category.update');
    Route::get('/category/show/{id}', 'CategoryController@show')->name('category.show');
    Route::delete('/categories/delete', 'CategoryController@multiple_categories_delete')->name('categories.delete');
    Route::post('/category/changestatus', 'CategoryController@changeStatus')->name('category.change_status');

    Route::get('/tags', 'TagController@index')->name('tags.list');
    Route::get('/tags/create', 'TagController@create')->name('tag.create');
    Route::post('/tags/create', 'TagController@store')->name('tag.store');
    Route::get('/tags/edit/{id}', 'TagController@edit')->name('tag.edit');
    Route::put('/tags/slug/update', 'TagController@slug')->name('tag.update.slug');
    Route::patch('/tags/update/{id}', 'TagController@update')->name('tag.update');
    Route::get('/tags/show/{id}', 'TagController@show')->name('tag.show');
    Route::get('/tag/delete/{id}', 'TagController@destroy')->name('tag.delete');
    Route::delete('/tags/delete', 'TagController@multiple_tags_delete')->name('tags.delete');
    Route::get('/tags/truncate', 'TagController@truncate')->name('tags.truncate');

    Route::get('/posts/{cat_id?}/{tag_id?}', 'PostController@index')->name('posts.list');
    Route::get('/post/create', 'PostController@create')->name('post.create');
    Route::post('/post/create', 'PostController@store')->name('post.store');
    Route::get('/post/edit/{id}', 'PostController@edit')->name('post.edit');
    Route::put('/post/slug/update', 'PostController@slug')->name('post.update.slug');
    Route::patch('/post/update/{id}', 'PostController@update')->name('post.update');
    Route::get('/post/show/{id}', 'PostController@show')->name('post.show');
    Route::get('/post/delete/{id}', 'PostController@destroy')->name('post.delete');
    Route::delete('/posts/delete', 'PostController@multiple_posts_delete')->name('posts.delete');
    Route::get('/posts/deleteall', 'PostController@deleteall')->name('posts.delete.all');
    Route::post('/post/meta/create', 'PostController@meta_create')->name('post.meta.store');
    Route::patch('/post/meta/update/{id}', 'PostController@meta_update')->name('post.meta.update');
    Route::delete('/post/meta/delete/{id}', 'PostController@meta_delete')->name('post.meta.delete');
    Route::post('/post/files/create', 'PostController@multiple_file_upload')->name('post.files.store');
    Route::get('/post/file/delete/{id}', 'PostController@file_delete')->name('post.file.delete');
    Route::patch('/post/meta-element/update/{id}', 'PostController@meta_element_update')->name('post.meta.element.update');
    Route::post('/post/changestatus', 'PostController@changeStatus')->name('post.change.status');

    //Route::get('/pages', 'PageController@index')->name('pages.list');
    Route::get('/pages', [PageController::class, 'index'])->name('pages.list');
    Route::get('/menus', 'MenuController@index')->name('menu.list');
    Route::get('/page/create', 'PageController@create')->name('page.create');
    Route::post('/page/create', 'PageController@store')->name('page.store');
    Route::get('/page/edit/{id}', 'PageController@edit')->name('page.edit');
        Route::get('/menu/edit/{id}', 'MenuController@edit')->name('menu.edit');
    Route::put('/page/slug/update', 'PageController@slug')->name('page.update.slug');
    Route::put('/page/update/status', 'PageController@update_page_status')->name('page.update.status');

    Route::patch('/page/update/{id}', 'PageController@update')->name('page.update');
    Route::get('/page/show/{id}', 'PageController@show')->name('page.show');
    Route::get('/page/delete/{id}', 'PageController@destroy')->name('page.delete');
    Route::delete('/menu/delete', 'MenuController@multiple_menu_delete')->name('menu.delete');
    Route::delete('/pages/delete', 'PageController@multiple_pages_delete')->name('pages.delete');
    Route::get('/pages/deleteall', 'PageController@deleteall')->name('pages.delete.all');
    Route::post('/page/meta/create', 'PageController@meta_create')->name('page.meta.store');
    Route::patch('/page/meta/update/{id}', 'PageController@meta_update')->name('page.meta.update');
    Route::delete('/page/meta/delete/{id}', 'PageController@meta_delete')->name('page.meta.delete');
    Route::patch('/page/meta-element/update/{id}', 'PageController@meta_element_update')->name('page.meta.element.update');
    Route::post('/page/changestatus', 'PageController@changeStatus')->name('page.change.status');
     Route::post('/page/update/status', 'MenuController@changeStatus')->name('menu.change.status');
    
    Route::get('/resources', 'MediaController@index')->name('resources.list');
    Route::get('/resources/create', 'MediaController@create')->name('resources.create');
    Route::post('/resources/create', 'MediaController@store')->name('resources.store');
    Route::delete('/resources/delete', 'MediaController@multiple_file_delete')->name('resources.delete');
    
    Route::get('/contact-emails', 'ContactFormController@index')->name('contact.forms.list');
    Route::get('/contact-emails/show/{id}', 'ContactFormController@show')->name('contact.form.show');

    Route::get('/subscribe-emails', 'SubscriberController@index')->name('subscribers.list');

    Route::get('/2fa/enable', 'Google2FAController@enableTwoFactor')->name('2fa.enable');
    Route::get('/2fa/disable', 'Google2FAController@disableTwoFactor')->name('2fa.disable');
    Route::get('/2fa/validate', 'Auth\AdminLoginController@getValidateToken')->name('2fa.validate');
    Route::post('/2fa/validate', ['middleware' => 'throttle:5', 'uses' => 'Auth\AdminLoginController@postValidateToken'])->name('2fa.post.validate');
    
    Route::match(['get','post','patch','delete'],'/301-redirects', 'SeoSettingController@redirectUrl')->name('301.redirect');

/******************************shrabani's functionility ....................**********************************************/
 Route::get('/content', 'CssController@index')->name('content.view');
        Route::post('/content/save', 'CssController@save_css')->name('content.save');
        Route::post('/content/getcontent', 'CssController@getcontent')->name('content.getcontent');

 Route::post('/menu/getmenu', 'MenuController@getmenu')->name('menu.getmenu');
 Route::post('/menu/addmenu', 'MenuController@addmenu')->name('menu.addmenu');
 Route::post('/menu/editmenu', 'MenuController@editmenu')->name('menu.editmenu');
  Route::post('/menu/changemenuname', 'MenuController@change_menu_name')->name('menu.change_menu_name');
Route::post('/menu/getmenuparent', 'MenuController@get_menu_parent')->name('menu.getmenuparent');
  Route::post('/menu/deletemenu', 'MenuController@delete_menu')->name('menu.deletemenu');


 Route::get('/menu', 'MenuController@creat_view')->name('menu.create');
/******************************end**********************************************/

    
    /***************** Extra Routes ***********************/
    Route::get('/appointments', 'ContactFormController@appointments')->name('appointments.list');


    Route::get('/roles', 'RoleController@index')->name('roles.list')->middleware('permission:admin.roles.list');
    Route::get('/role/create', 'RoleController@create')->name('role.create')->middleware('permission:admin.role.create');
    Route::post('/role/create', 'RoleController@store')->name('role.store')->middleware('permission:admin.role.store');
    Route::get('/role/edit/{id}', 'RoleController@edit')->name('role.edit')->middleware('permission:admin.role.edit');
    Route::patch('/role/update/{id}', 'RoleController@update')->name('role.update')->middleware('permission:admin.role.update');
    Route::get('/role/delete/{id}', 'RoleController@destroy')->name('role.delete')->middleware('permission:admin.role.delete');

    Route::get('/permissions', 'PermissionController@index')->name('permissions.list')->middleware('permission:admin.permissions.list');
    Route::get('/permission/create', 'PermissionController@create')->name('permission.create')->middleware('permission:admin.permission.create');
    Route::post('/permission/create', 'PermissionController@store')->name('permission.store')->middleware('permission:admin.permission.store');
    Route::get('/permission/edit/{id}', 'PermissionController@edit')->name('permission.edit')->middleware('permission:admin.permission.edit');
    Route::patch('/permission/update/{id}', 'PermissionController@update')->name('permission.update')->middleware('permission:admin.permission.update');
    Route::get('/permission/delete/{id}', 'PermissionController@destroy')->name('permission.delete')->middleware('permission:admin.permission.delete');

    Route::get('/role-permissions', 'RolePermissionController@index')->name('role.permissions.list')->middleware('permission:admin.role.permissions.list');
    Route::post('/set-unset-permission', 'RolePermissionController@manage')->name('role.permissions.manage')->middleware('permission:admin.role.permissions.manage');

    Route::get('/admin-users', 'AdminUserController@index')->name('adm.users.list')->middleware('permission:admin.adm.users.list');
    Route::get('/admin-user/create', 'AdminUserController@create')->name('adm.user.create')->middleware('permission:admin.adm.user.create');
    Route::post('/admin-user/create', 'AdminUserController@store')->name('adm.user.store')->middleware('permission:admin.adm.user.store');
    Route::get('/admin-user/edit/{id}', 'AdminUserController@edit')->name('adm.user.edit')->middleware('permission:admin.adm.user.edit');
    Route::patch('/admin-user/update/{id}', 'AdminUserController@update')->name('adm.user.update')->middleware('permission:admin.adm.user.update');
    Route::get('/admin-user/change_password/{id}', 'AdminUserController@showPasswordFrom')->name('adm.user.change_password')->middleware('permission:admin.adm.user.change_password');
    Route::patch('/admin-user/change_password/{id}', 'AdminUserController@changePassword')->name('adm.user.password.create')->middleware('permission:admin.adm.user.password.create');
    Route::get('/admin-user/show/{id}', 'AdminUserController@show')->name('adm.user.show')->middleware('permission:admin.adm.user.show');
    Route::post('/admin-user/changestatus', 'AdminUserController@changeStatus')->name('adm.user.change_status')->middleware('permission:admin.adm.user.change_status');
    Route::get('/admin-user/delete/{id}', 'AdminUserController@destroy')->name('adm.user.delete')->middleware('permission:admin.adm.user.delete');
    Route::post('/admin-users/delete', 'AdminUserController@multiple_user_delete')->name('adm.users.delete')->middleware('permission:admin.adm.users.delete');
    Route::post('/set-unset-admin-user-permission', 'AdminUserController@manage')->name('adm.user.permissions.manage')->middleware('permission:admin.adm.user.permissions.manage');

});

Route::group(['middleware' => ['RedirectUrl']], function () {
   

    Route::get('/', 'PageController@index')->name('home-page');
Route::post('contact-form', 'PageController@contact_form')->name('contact-form');
Route::post('subscribe-form', 'PageController@subscribe_form')->name('subscribe-form');

Route::get('404',['as'=>'404','uses'=>'ErrorHandlerController@errorCode404']);
Route::get('thank-you', 'PageController@thankyou')->name('thankyou');
Route::post('booking', 'PageController@booking_enquiry')->name('booking.enquiry');
Route::post('get-time-step', 'PageController@generate_time_step')->name('get.time.step');
Route::get('{parent}/{slug1}/{slug2}/{slug3}', 'PageController@othersub3')->name('sub3');;
Route::get('{parent}/{slug1}/{slug2}', 'PageController@othersub2')->name('sub2');;
Route::get('{parent}/{slug}', 'PageController@othersub')->name('sub');
Route::get('{slug}', 'PageController@other');
Route::get('verify/{email}/{verifyToken}', 'Auth\RegisterController@sendEmailDone')->name('sendEmailDone');



});

Route::group(['namespace' => 'User', ['middleware' => 'prevent-back-history']], function() {

	Route::get('/register', 'Auth\RegisterController@showRegistrationForm')->name('register');
    Route::post('/register', 'Auth\RegisterController@register')->name('register');
	Route::get('/login', 'Auth\LoginController@showLoginForm')->name('login');
    Route::post('/login', 'Auth\LoginController@login')->name('login');
    Route::post('/logout', 'Auth\LoginController@logout')->name('logout');
    Route::post('/password/email', 'Auth\ForgotPasswordController@sendResetLinkEmail')->name('password.email');
    Route::get('/password/reset', 'Auth\ForgotPasswordController@showLinkRequestForm')->name('password.request');
    Route::post('/password/reset', 'Auth\ResetPasswordController@reset')->name('password.update');
    Route::get('/password/reset/{token}', 'Auth\ResetPasswordController@showResetForm')->name('password.reset');

    Route::get('email/verify', 'Auth\VerificationController@show')->name('verification.notice');
    Route::get('email/verify/{id}', 'Auth\VerificationController@verify')->name('verification.verify');
    Route::get('email/resend', 'Auth\VerificationController@resend')->name('verification.resend');

	Route::get('/home', 'HomeController@index')->name('home');

});


